@@ -1,3 +1,3 @@
 """Plugantic: Simplify extendable composition with Pydantic."""
 from ._consts import version as __version__
-from .plugin import PluginModel, PluginDowncastHandler
+from .plugin import PluginModel, Field
